import dotenv
import re

def check_mail_fomat(mail_address: str):
    if not mail_address:
        return False
    if not re.match(r'^[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)*@[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)+$', mail_address):
        return False
    return True

def load_env(env_path: str):
    dotenv.load_dotenv(dotenv_path=env_path, override=True)


import logging


class Pusher:
    def __init__(self, driver_name: str, driver_config: dict):
        self.driver_name = driver_name
        self.driver_config = driver_config
        self.logger = logging.getLogger(__name__)
        self.logger.setLevel(logging.DEBUG)
        self.logger.addHandler(logging.StreamHandler())

        self.drivers = ['mail']

        if driver_name not in self:
            raise Exception(f'Driver {driver_name} not found')
        self.driver = self[driver_name](driver_config)

    def push(self, job: dict):
        self.logger.info("Pushing job %s", job)
        self.driver.auth()
        self.driver.send(job['to'], job['subject'], job['content'], job['attachments'])

    def __contains__(self, driver_name):
        return driver_name in self.drivers

    def __getitem__(self, driver_name):
        if driver_name == 'mail':
            from jobpusher.drivers.mail import MailDriver
            return MailDriver


from setuptools import setup, find_packages

with open('README.md', 'r') as f:
    long_description = f.read()

with open('LICENSE', 'r') as f:
    license = f.read()

with open('requirements.txt', 'r') as f:
    requirements = f.read().splitlines()

setup(
    name='jobpusher',
    version='0.0.4',
    description='Job Pusher',
    author='TankNee',
    author_email='nee@tanknee.cn',
    long_description=long_description,
    long_description_content_type="text/markdown",
    license=license,
    packages=find_packages(include=['jobpusher', 'jobpusher.*']),
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License'
    ],
    keywords='jobpusher notifier pusher',
    install_requires=requirements,
    include_package_data=True,
)
